import React, { useState, useEffect } from 'react';
import { useParams, Link as RouterLink } from 'react-router-dom'; // Renommez Link pour éviter les conflits avec MUI Button
import axios from 'axios';
import {
  Box,          // Conteneur générique pour le style
  Typography,   // Titres, paragraphes
  Button,       // Bouton "Postuler"
  CircularProgress, // Indicateur de chargement
  Paper,        // Pour encadrer le contenu de l'offre
  IconButton,
} from '@mui/material';
import ArrowBackIcon from '@mui/icons-material/ArrowBack'; // Icône pour le bouton retour
import FavoriteBorderIcon from '@mui/icons-material/FavoriteBorder';
import FavoriteIcon from '@mui/icons-material/Favorite';

import type { JobOffer } from '../types'; // Use type-only import

const API_BASE_URL = 'http://localhost:3000/api/jobs'; // Assurez-vous que c'est la bonne URL de votre API backend

const JobDetail: React.FC = () => {
  const { id } = useParams<{ id: string }>();
  const [job, setJob] = useState<JobOffer | null>(null);
  const [loading, setLoading] = useState<boolean>(true);
  const [error, setError] = useState<string | null>(null);
  const [isFavorite, setIsFavorite] = useState<boolean>(false);

  useEffect(() => {
    const fetchJobDetail = async () => {
      setLoading(true);
      setError(null);
      try {
        const response = await axios.get<JobOffer>(`${API_BASE_URL}/${id}`);
        setJob(response.data);
        // Vérifie si l'offre est dans les favoris
        const favorites = JSON.parse(localStorage.getItem('jobFavorites') || '[]');
        setIsFavorite(favorites.includes(response.data.id));
      } catch (err) {
        console.error('Erreur lors de la récupération des détails de l\'offre:', err);
        if (axios.isAxiosError(err) && err.response?.status === 404) {
          setError('Offre d\'emploi non trouvée.');
        } else {
          setError('Impossible de charger les détails de l\'offre. Veuillez réessayer.');
        }
      } finally {
        setLoading(false);
      }
    };

    if (id) {
      fetchJobDetail();
    }
  }, [id]);

  const handleApplyClick = () => {
    if (job?.urlOffre) {
      window.open(job.urlOffre, '_blank', 'noopener,noreferrer');
    } else {
      // Utilisation d'un alert MUI ou d'un SnackBar serait mieux ici,
      // mais pour l'instant, gardons l'alert JS pour la simplicité.
      alert("Désolé, l'URL de candidature n'est pas disponible pour cette offre.");
    }
  };

  const handleToggleFavorite = () => {
    if (!job) return;

    let favorites = JSON.parse(localStorage.getItem('jobFavorites') || '[]');
    if (isFavorite) {
      // Supprimer des favoris
      favorites = favorites.filter((favId: string) => favId !== job.id);
    } else {
      // Ajouter aux favoris
      favorites.push(job.id);
    }
    localStorage.setItem('jobFavorites', JSON.stringify(favorites));
    setIsFavorite(!isFavorite);
  };

  if (loading) {
    return (
      <Box sx={{ display: 'flex', justifyContent: 'center', alignItems: 'center', height: '80vh' }}>
        <CircularProgress />
        <Typography variant="body1" sx={{ ml: 2, color: 'text.secondary' }}>
          Chargement des détails de l'offre...
        </Typography>
      </Box>
    );
  }

  if (error) {
    return (
      <Box sx={{ textAlign: 'center', py: 4, maxWidth: '800px', mx: 'auto' }}>
        <Typography variant="h6" color="error" sx={{ mb: 2 }}>Erreur : {error}</Typography>
        <Button component={RouterLink} to="/" variant="outlined">
          Retour à la recherche
        </Button>
      </Box>
    );
  }

  if (!job) {
    return (
      <Box sx={{ textAlign: 'center', py: 4, maxWidth: '800px', mx: 'auto' }}>
        <Typography variant="h6" sx={{ mb: 2, color: 'text.secondary' }}>Aucun détail d'offre disponible.</Typography>
        <Button component={RouterLink} to="/" variant="outlined">
          Retour à la recherche
        </Button>
      </Box>
    );
  }

  return (
    <Box sx={{
      padding: { xs: 2, md: 4 }, // Padding réactif
      maxWidth: '800px',
      margin: '20px auto',
      backgroundColor: 'background.default', // Fond de la page (non du Paper)
    }}>
      <Button
        component={RouterLink} // Utilisez RouterLink pour la navigation interne
        to="/"
        startIcon={<ArrowBackIcon />}
        variant="outlined" // Style de bouton 'outlined' comme dans Notion
        sx={{ mb: 3 }} // Marge en bas
      >
        Retour à la recherche d'offres
      </Button>

      <Paper elevation={0} sx={{ // Utilisation de Paper pour le bloc de contenu de l'offre
        p: { xs: 3, md: 4 }, // Padding
        borderRadius: '12px', // Bords arrondis
        boxShadow: '0px 4px 10px rgba(0, 0, 0, 0.05)', // Ombre douce
        backgroundColor: 'background.paper', // Fond blanc du Paper
        position: 'relative',
      }}>
        {/* Bouton Favori */}
        <IconButton
          aria-label={isFavorite ? "Retirer des favoris" : "Ajouter aux favoris"}
          onClick={handleToggleFavorite}
          sx={{
            position: 'absolute',
            top: 16,
            right: 16,
            color: isFavorite ? 'secondary.main' : 'text.secondary',
            transition: 'transform 0.2s ease-in-out',
            '&:hover': {
              transform: 'scale(1.1)',
              color: isFavorite ? 'secondary.dark' : 'secondary.main',
            },
          }}
        >
          {isFavorite ? <FavoriteIcon /> : <FavoriteBorderIcon />}
        </IconButton>

        <Typography variant="h4" component="h1" gutterBottom sx={{ color: 'text.primary', pr: 6 }}>
          {job.title}
        </Typography>
        <Typography variant="body1" sx={{ mb: 1.5, color: 'text.secondary' }}>
          <strong>Entreprise :</strong> {job.companyName || 'N/A'}
        </Typography>
        <Typography variant="body1" sx={{ mb: 1.5, color: 'text.secondary' }}>
          <strong>Localisation :</strong> {job.locationLabel || job.cityName || 'N/A'}
        </Typography>
        <Typography variant="body1" sx={{ mb: 1.5, color: 'text.secondary' }}>
          <strong>Contrat :</strong> {job.contractLabel || job.contractType || 'N/A'}
        </Typography>
        <Typography variant="body1" sx={{ mb: 1.5, color: 'text.secondary' }}>
          <strong>Publiée le :</strong> {new Date(job.publicationDate).toLocaleDateString()}
        </Typography>
        {job.romeLabel && (
          <Typography variant="body1" sx={{ mb: 1.5, color: 'text.secondary' }}>
            <strong>ROME :</strong> {job.romeLabel}
          </Typography>
        )}
        {job.postalCode && (
          <Typography variant="body1" sx={{ mb: 1.5, color: 'text.secondary' }}>
            <strong>Code postal :</strong> {job.postalCode}
          </Typography>
        )}
        {job.departmentCode && (
          <Typography variant="body1" sx={{ mb: 1.5, color: 'text.secondary' }}>
            <strong>Département :</strong> {job.departmentCode}
          </Typography>
        )}

        <Typography variant="h5" component="h2" sx={{ mt: 4, mb: 2, color: 'text.primary' }}>
          Description
        </Typography>
        <Typography variant="body1" sx={{ lineHeight: 1.7, whiteSpace: 'pre-wrap', color: 'text.primary' }}>
          {job.description}
        </Typography>

        {job.urlOffre && (
          <Box sx={{ mt: 4, textAlign: 'center' }}>
            <Button
              variant="contained" // Utilisez le style 'contained' du thème
              color="secondary" // Utilisez la couleur secondaire pour le bouton "Postuler"
              onClick={handleApplyClick}
              sx={{
                px: 4, // Padding horizontal
                py: 1.5, // Padding vertical
                fontSize: '1.05em',
                borderRadius: '8px', // Bords arrondis
              }}
            >
              Postuler maintenant
            </Button>
          </Box>
        )}
      </Paper>
    </Box>
  );
};

export default JobDetail;
